@@ -1,4 +1,5 @@
 use strict;
+use Log::Log4perl qw(:easy);
 use WWW::Mechanize::Chrome;
 
 my $mech = WWW::Mechanize::Chrome->new();
@@ -16,11 +17,15 @@ dump-links.pl - Dump links on a webpage
 
 =head1 SYNOPSIS
 
-dump-links.pl
+From the examples directory:
+
+  perl dump-links.pl
 
 =head1 DESCRIPTION
 
-This program demonstrates how to read elements out of the Chrome
-DOM and how to get at text within nodes.
+This program demonstrates how to read elements out of the Chrome DOM
+and how to get at text within nodes.  It prints links with the CSS
+class "download" from a file provided with the distribution.
 
-=cut
\ No newline at end of file
+
+=cut
