@@ -1,6 +1,7 @@
 use strict;
 use File::Spec;
 use File::Basename 'dirname';
+use Log::Log4perl qw(:easy);
 use WWW::Mechanize::Chrome;
 
 my $mech = WWW::Mechanize::Chrome->new();
@@ -21,3 +22,16 @@ sub show_screen() {
 $mech->get('http://act.yapc.eu/gpw2017');
 
 show_screen;
+
+=head1 NAME
+
+url-to-image.pl
+
+=head1 SYNOPSIS
+
+  perl url-to-image.pl
+
+=head1 DESCRIPTION
+
+This example fetches a web page and creates a screenshot in PNG format
+in the script's directory.
